@@ -55,11 +55,35 @@ class Element(object):
                 Element symbol, e.g., "H", "Fe"
         '''
         self._data = _pt_data[symbol]
+        #Store key variables for quick access
         self._z = self._data['Atomic no']
         self._symbol = symbol
+        self._x = self._data.get('X', 0)
         
         Element._all_elements[tuple([symbol])] = self
-        
+    
+    @property
+    def average_ionic_radius(self):
+        """
+        Average ionic radius for element in pm.
+        The average is taken over all oxidation states of the element for which data is present.
+        """
+        if 'Ionic_radii' in self._data:
+            return sum(self._data['Ionic_radii'].values())/len(self._data['Ionic_radii'])
+        else:
+            return 0
+    
+    @property
+    def ionic_radii(self):
+        """
+        All ionic radii of the element as a dict of {oxidation state: ionic radii}.
+        Radii are given in pm.
+        """
+        if 'Ionic_radii' in self._data:
+            return {int(k):v for k,v in self._data['Ionic_radii'].items()}
+        else:
+            return {}
+    
     @property
     def Z(self):
         """Atomic number"""
@@ -73,10 +97,7 @@ class Element(object):
     @property
     def X(self):
         """Electronegativity"""
-        if 'X' in self._data:
-            return self._data['X']
-        else:
-            return 0
+        return self._x
         
     @property
     def number(self):
@@ -277,7 +298,15 @@ class Element(object):
         useful for getting correct formulas.  For example, FeO4PLi is automatically
         sorted in LiFePO4.
         '''
-        return (self.X - other.X)
+        return (self._x - other._x)
+    
+    def __lt__(self, other):
+        '''
+        Sets a default sort order for atomic species by electronegativity.  Very
+        useful for getting correct formulas.  For example, FeO4PLi is automatically
+        sorted in LiFePO4.
+        '''
+        return (self._x < other._x)
 
     @staticmethod       
     def from_Z(z):
@@ -511,7 +540,14 @@ class Specie(object):
         Sets a default sort order for atomic species by electronegativity, followed by oxidation state. 
         '''
         return (self.X - other.X) * 100 + (self.oxi_state - other.oxi_state)
-        
+    
+    @property
+    def ionic_radius(self):
+        """
+        Ionic radius of specie. Returns None if data is not present.
+        """
+        return self.ionic_radii.get(self._oxi_state, None)
+    
     @property
     def oxi_state(self):
         """
