@@ -81,7 +81,7 @@ class Poscar(VaspInput):
             syms = [site.specie.symbol for site in struct]
             for s in itertools.groupby(syms):
                 self._site_symbols.append(s[0])
-                self._natoms.append(len(s))
+                self._natoms.append(len(tuple(s[1])))
             self._true_names = True
             if selective_dynamics:
                 self.set_selective_dynamics(selective_dynamics)
@@ -446,9 +446,9 @@ class Incar(dict, VaspInput):
                 return int(val)
             
         except:
-            return val
+            return val.capitalize()
               
-        return val
+        return val.capitalize()
             
     def diff(self, other):
         """
@@ -473,8 +473,8 @@ class Incar(dict, VaspInput):
                 similar_param[k1] = v1
         for k2,v2 in other.items():
             if k2 not in similar_param and k2 not in different_param:
-                if k1 not in self:
-                    different_param[k1] = {"INCAR1": 'Default', "INCAR2": v2}
+                if k2 not in self:
+                    different_param[k2] = {"INCAR1": 'Default', "INCAR2": v2}
         return {'Same' : similar_param, 'Different': different_param}
                 
     def __add__(self, other):
@@ -1011,7 +1011,7 @@ class Vasprun(object):
         d['input']['kpoints']['actual_points'] = [{'abc':list(self.actual_kpoints[i]), 'weight':self.actual_kpoints_weights[i]} for i in xrange(len(self.actual_kpoints))] 
         d['input']['potcar'] = [s.split(" ")[1] for s in self.potcar_symbols]
         d['input']['parameters'] = {k:v for k,v in self.parameters.items()}
-        d['input']['lattice_rec'] = self.lattice_rec
+        d['input']['lattice_rec'] = self.lattice_rec.to_dict
         
         d['output'] = {}
         d['output']['ionic_steps'] = clean_json(self.ionic_steps)
@@ -1251,8 +1251,7 @@ class VasprunHandler(xml.sax.handler.ContentHandler):
                     self.pos = np.array([float(x) for x in re.split("\s+",self.posstr.getvalue().strip())])
                     self.pos.shape = (len(self.atomic_symbols), 3)
                     self.structures.append(Structure(self.lattice, self.atomic_symbols, self.pos))
-                    self.lattice_rec = np.array([float(x) for x in re.split("\s+",self.latticerec.getvalue().strip())])
-                    self.lattice_rec.shape = (3,3)
+                    self.lattice_rec = Lattice([float(x) for x in re.split("\s+",self.latticerec.getvalue().strip())])
                     self.read_structure = False
             elif self.read_dos:
                 try:
@@ -1398,12 +1397,25 @@ class Outcar(object):
     be very different depending on which "type of run" performed.
 
     Creating the OUTCAR class with a filename reads "regular parameters" that are always present.
-    Presently these are just the magnetization, mag[ion] (magnetization per ion) and magtot (total magnetization)
-
+    
+    Default attributes:
+        magnetization:
+            Magnetization on each ion as a tuple of dict, e.g., ({'d': 0.0, 'p': 0.003, 's': 0.002, 'tot': 0.005}, ... )
+            Note that this data is not always present.  LORBIT must be set to some other value than the default.
+        charge:
+            Charge on each ion as a tuple of dict, e.g., ({'p': 0.154, 's': 0.078, 'd': 0.0, 'tot': 0.232}, ...)
+            Note that this data is not always present.  LORBIT must be set to some other value than the default.
+        is_stopped:
+            True if OUTCAR is from a stopped run (using STOPCAR, see Vasp Manual).
+        run_stats:
+            Various useful run stats as a dict including 'System time (sec)', 'Total CPU time used (sec)'
+            'Elapsed time (sec)', 'Maximum memory used (kb)', 'Average memory used (kb)', 'User time (sec)'.
+                
+            
     One can then call a specific reader depending on the type of run being perfromed. These are currently:
-       readIGPAR()
-       readLEPSILON()
-       readLCALCPOL()
+       read_igpar()
+       read_lepsilon()
+       read_lcalcpol()
 
     See the documentation of those methods for more documentation.
     
@@ -1412,40 +1424,46 @@ class Outcar(object):
     """
     def __init__(self, filename):
         self.filename = filename
-        
+        self.is_stopped = False
         with file_open_zip_aware(filename, "r") as f:
             lines = f.readlines()
         
-            read_charge = False
-            read_mag = False
-            charge = []
-            mag = []
-            header = []
-            for line in lines:
-                clean = line.strip()
-                if clean == "total charge":
-                    read_charge = True
-                    charge = []
-                elif clean == "magnetization (x)":
-                    read_mag = True
-                    mag = []
-                elif read_charge or read_mag:
-                    if clean.startswith("# of ion"):
-                        header = re.split("\s{2,}", line.strip())
-                    elif clean.startswith("tot"):
-                        read_charge = False
-                        read_mag = False
-                    else:
-                        m = re.match("\s*(\d+)\s+(([\d\.\-]+)\s+)+", clean)
-                        if m:
-                            to_append = charge if read_charge else mag
-                            data = re.findall("[\d\.\-]+", clean)
-                            to_append.append({header[i]:float(data[i]) for i in xrange(1,len(header))})
-            
+        read_charge = False
+        read_mag = False
+        charge = []
+        mag = []
+        header = []
+        run_stats = {}
+        for line in lines:
+            clean = line.strip()
+            if clean == "total charge":
+                read_charge = True
+                charge = []
+            elif clean == "magnetization (x)":
+                read_mag = True
+                mag = []
+            elif read_charge or read_mag:
+                if clean.startswith("# of ion"):
+                    header = re.split("\s{2,}", line.strip())
+                elif clean.startswith("tot"):
+                    read_charge = False
+                    read_mag = False
+                else:
+                    m = re.match("\s*(\d+)\s+(([\d\.\-]+)\s+)+", clean)
+                    if m:
+                        to_append = charge if read_charge else mag
+                        data = re.findall("[\d\.\-]+", clean)
+                        to_append.append({header[i]:float(data[i]) for i in xrange(1,len(header))})
+            elif line.find('soft stop encountered!  aborting job') != -1:
+                self.is_stopped = True
+            elif re.search("\((sec|kb)\):", line):
+                tok = line.strip().split(":")
+                run_stats[tok[0].strip()] = float(tok[1].strip())
+            self.run_stats = run_stats
             self.magnetization = tuple(mag)
             self.charge = tuple(charge)
 
-    def read_IGPAR(self):
+    def read_igpar(self):
         """ 
         Renders accessible:
             er_ev = e<r>_ev (dictionary with Spin.up/Spin.down as keys)
@@ -1510,7 +1528,7 @@ class Outcar(object):
             self.er_bp_tot = None
             raise Exception("IGPAR OUTCAR could not be parsed.")
 
-    def readLEPSILON(self):
+    def read_lepsilon(self):
         # variables to be filled
         try:
             search = []
@@ -1567,7 +1585,7 @@ class Outcar(object):
         except:
             raise Exception("LEPSILON OUTCAR could not be parsed.")
 
-    def readLCALCPOL(self):
+    def read_lcalcpol(self):
         # variables to be filled
         self.p_elec = None
         self.p_ion = None
@@ -1835,7 +1853,78 @@ class Procar(object):
                 else:
                     self.data[index] = np.array(linefloatdata) * weight
 
+class Oszicar(object):
+    """
+    A basic parser for an OSZICAR output from VASP.  In general, while the OSZICAR is useful for a quick look
+    at the output from a VASP run, we recommend that you use the Vasprun parser instead, which gives far richer information
+    about a run.
+    
+    Attributes:
+        electronic_steps:
+            All electronic steps as a list of list of dict. e.g., 
+            [[{'rms': 160.0, 'E': 4507.24605593, 'dE': 4507.2, 'N': 1, 'deps': -17777.0, 'ncg': 16576}, ...], [....]
+            where electronic_steps[index] refers the list of electronic steps in one ionic_step, electronic_steps[index][subindex]
+            refers to a particular electronic step at subindex in ionic step at index.  The dict of properties depends on the type
+            of VASP run, but in general, "E", "dE" and "rms" should be present in almost all runs.
+        ionic_steps:
+            All ionic_steps as a list of dict, e.g.,
+            [{'dE': -526.36, 'E0': -526.36024, 'mag': 0.0, 'F': -526.36024}, ...]
+            This is the typical output from VASP at the end of each ionic step.
 
+    Please refer to the vasp manual for the definition for each of the terms.
+            
+    In addition, two convenience properties, all_energies and final_energy are provided for quick access to the commonly used 
+    energetic output from a run.  Please refer to the doc for those two methods for details.    
+    """
+    
+    def __init__(self, filename):
+        electronic_steps = []
+        ionic_steps = []
+        ionic_pattern = re.compile("(\d+)\s+F=\s*([\d\-\.E\+]+)\s+E0=\s*([\d\-\.E\+]+)\s+d\s*E\s*=\s*([\d\-\.E\+]+)\s+mag=\s*([\d\-\.E\+]+)")
+        electronic_pattern = re.compile("\s*\w+\s*:(.*)")
+        def smart_convert(header, num):
+            if header == "N" or header == "ncg":
+                return int(num)
+            return float(num)
+        header = []
+        with open(filename, 'r') as fid:
+            for line in fid.readlines():
+                m = electronic_pattern.match(line)
+                if m:
+                    toks = re.split("\s+", m.group(1).strip())
+                    data = {header[i]:smart_convert(header[i], toks[i]) for i in xrange(len(toks))}
+                    if toks[0] == '1':
+                        electronic_steps.append([data])
+                    else:
+                        electronic_steps[-1].append(data)
+                elif ionic_pattern.match(line.strip()):
+                    m = ionic_pattern.match(line.strip())
+                    ionic_steps.append({'F':float(m.group(2)),'E0':float(m.group(3)),'dE':float(m.group(4)),'mag':float(m.group(5))})
+                elif re.match("^\s*N\s+E\s*", line):
+                    header = re.split("\s+", line.strip().replace("d eps", "deps"))
+        self.electronic_steps = electronic_steps
+        self.ionic_steps = ionic_steps
+
+    @property
+    def all_energies(self):
+        """
+        Compilation of all energies from all electronic steps and ionic steps as a list of list of energies, e.g.,
+        [[4507.24605593, 143.824705755, -512.073149912, -547.713139455, ...], ...]
+        """
+        all_energies = []
+        for i in xrange(len(self.electronic_steps)):
+            energies = [step['E'] for step in self.electronic_steps[i]]
+            energies.append(self.ionic_steps[i]['F'])
+            all_energies.append(energies)
+        return all_energies
+    
+    @property
+    def final_energy(self):
+        """
+        Final energy from run.
+        """
+        return self.ionic_steps[-1]['F']
+    
 class VaspParserError(Exception):
     '''
     Exception class for Structure.
